gchecky.model.checkout_flow_support_t

Package gchecky :: Module model :: Class checkout_flow_support_t |
[hide private]
[frames] | no frames]

# Class checkout_flow_support_t

source code

    object --+
             |
     gxml.Node --+
                 |
                checkout_flow_support_t

    >>> test_node(
    ...   checkout_flow_support_t(
    ...     parameterized_urls = [
    ...         parameterized_url_t(
    ...             url='http://google.com/',
    ...             parameters=[url_parameter_t(name='a', type='buyer-id')]
    ...         ),
    ...         parameterized_url_t(
    ...             url='http://yahoo.com/',
    ...             parameters=[url_parameter_t(name='a', type='shipping-city'),
    ...                         url_parameter_t(name='b', type='tax-amount')]
    ...         ),
    ...         parameterized_url_t(
    ...             url='http://mozilla.com/',
    ...             parameters=[url_parameter_t(name='a', type='order-total'),
    ...                         url_parameter_t(name='b', type='shipping-region'),
    ...                         url_parameter_t(name='c', type='shipping-country-code')]
    ...         )
    ...     ],
    ...   )
    ... ,
    ... '''
    ... <node>
    ...   <parameterized-urls>
    ...     <parameterized-url url="http://google.com/">
    ...       <parameters>
    ...         <url-parameter name="a" type="buyer-id"/>
    ...       </parameters>
    ...     </parameterized-url>
    ...     <parameterized-url url="http://yahoo.com/">
    ...       <parameters>
    ...         <url-parameter name="a" type="shipping-city"/>
    ...         <url-parameter name="b" type="tax-amount"/>
    ...       </parameters>
    ...     </parameterized-url>
    ...     <parameterized-url url="http://mozilla.com/">
    ...       <parameters>
    ...         <url-parameter name="a" type="order-total"/>
    ...         <url-parameter name="b" type="shipping-region"/>
    ...         <url-parameter name="c" type="shipping-country-code"/>
    ...       </parameters>
    ...     </parameterized-url>
    ...   </parameterized-urls>
    ... </node>
    ... '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| edit_cart_url = `Url:PATH(edit-cart-url):OPT`
| continue_shopping_url = `Url:PATH(continue-shopping-url):OPT`
| tax_tables = `Node:PATH(tax-tables):OPT:{ tax_tables_t }`
| shipping_methods = `Node:PATH(shipping-methods):OPT:{ shipping_`...``
| merchant_calculations = `Node:PATH(merchant-calculations):OPT:{`...``
| request_buyer_phone_number = `gxml.Boolean('request-buyer-phone`...``
| platform_id = `Long:PATH(platform-id):OPT`
| analytics_data = `String:PATH(analytics-data):OPT`
| parameterized_urls = `List:PATH(parameterized-urls):OP`...``
| _fields = ``{``'``analytics_data``'``:` String:PATH(analytics-data):OPT`,` `...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### shipping_methods Value:
      Node:PATH(shipping-methods):OPT:{ shipping_methods_t }

  ### merchant_calculations Value:
      Node:PATH(merchant-calculations):OPT:{ merchant_calculations_t }

  ### request_buyer_phone_number Value:
      gxml.Boolean('request-buyer-phone-number', required= False)

  ### parameterized_urls Value:
      List:PATH(parameterized-urls):OPT:[
          Node:PATH(parameterized-url):REQ:{ parameterized_url_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'analytics_data': String:PATH(analytics-data):OPT,
       'continue_shopping_url': Url:PATH(continue-shopping-url):OPT,
       'edit_cart_url': Url:PATH(edit-cart-url):OPT,
       'merchant_calculations': Node:PATH(merchant-calculations):OPT:{ merch
      ant_calculations_t },
       'parameterized_urls': List:PATH(parameterized-urls):OPT:[
          Node:PATH(parameterized-url):REQ:{ parameterized_url_t }
      ],
      ...